@@ -50,5 +50,5 @@ test_that("cXlayout11", {
 test_that("cXlayout12", {
     check_ui_test(cXlayout12())
 
-    message('middle section too small at default height - working as designed')
+    warning('middle section too small at default height - working as designed')
 })
